#! /usr/bin/env python

from distutils.core import setup, Extension

longdesc = """This is a simple SWIG wrapper on C++ fastNLO Reader interface."""

## Extension definition
import os
wrapsrc = './fastnlo_wrap.cc'
incdir_src = os.path.abspath('../include')
incdir_build = os.path.abspath('../fastnlotoolkit/include')
libdir = os.path.abspath('../fastnlotoolkit')

incdir_lhapdf = '/usr/include'
libdir_lhapdf = '/usr/lib/x86_64-linux-gnu'
libdir_fnlo = '/usr/lib'

## Add -std=gnu++11 explicitly to work around issue on Centos7
cxxargs = '-g -O2 -fdebug-prefix-map=/var/www/debian/fastnlo/fastnlo-toolkit-2.3.1pre2411=. -fstack-protector-strong -Wformat -Werror=format-security -std=gnu++11'.split()
ldargs = '-Wl,-z,relro -L/usr/lib -L/usr/lib'.split()
ext = Extension('_fastnlo',
                [wrapsrc],
                include_dirs=[incdir_src, incdir_build,incdir_lhapdf],
                library_dirs=[libdir,libdir_lhapdf, os.path.join(libdir,'.libs')],
                runtime_library_dirs=[libdir_lhapdf,libdir_fnlo],
                extra_compile_args = cxxargs,
                extra_link_args = ldargs,
                libraries=['fastnlotoolkit','LHAPDF'],
                )

## Setup definition
setup(name = 'fastnlo',
      version = '2.3.1pre',
      #include_package_data = True,
      ext_modules=[ext],
      py_modules = ['fastnlo'],
      author = ['fastNLO'],
      url = 'http://projects.hepforge.org/fastnlo/',
      description = 'A SWIG wrapper on C++ fastNLO interface.',
      long_description = longdesc,
      )
